@@ -4,6 +4,8 @@
 # 14 April 2010: set id.n = 0. J. Fox
 # 15 April 2010; rewrite showLabels
 # 25 May 2010 added grid() to plots, S. Weisberg
+# 15 August 2010, fixed so col= works correctly with plot, but not Boxplot
+# 15 August 2010, deleted pch= argument, as it wasn't used
 
 residualPlots <- function(model, ...){UseMethod("residualPlots")}
 
@@ -79,8 +81,8 @@ residualPlot.default <- function(model, variable = "fitted", type = "pearson",
                  id.method = "xy", 
                  id.n = if(id.method[1]=="identify") Inf else 0,
                  id.cex=1, id.col=palette()[1], 
-                 col = palette()[2], col.lines = col[1], 
-                 xlab, ylab, pch = 1, lwd = 1, lty = 1,  
+                 col = palette()[1], col.lines = palette()[2], 
+                 xlab, ylab, lwd = 1, lty = 1,  
                  grid=TRUE, ...) {
 # two functions modified from 'scatterplot' function:
 	logged <- function(axis=c("x", "y")){
@@ -106,7 +108,8 @@ residualPlot.default <- function(model, variable = "fitted", type = "pearson",
      paste(toupper(substring(string, 1, 1)), substring(string, 2), sep="")}
  if(missing(labels)) 
       labels <-  names(residuals(model)[!is.na(residuals(model))])
- ylab <- paste(string.capitalize(type), "residuals")
+ ylab <- if(!missing(ylab)) ylab else
+         paste(string.capitalize(type), "residuals")
  column <- match(variable, names(model$model))
  if(is.na(column) && variable != "fitted")
    stop(paste(variable, "is not a term in the mean function"))
@@ -114,6 +117,7 @@ residualPlot.default <- function(model, variable = "fitted", type = "pearson",
  lab <- if(variable == "fitted") {
     if(inherits(model, "glm")) 
        "Linear Predictor" else "Fitted values"} else variable
+ lab <- if(!missing(xlab)) xlab else lab
  ans <-
    if(inherits(horiz, "poly")) {
        horiz <- horiz[ , 1]
@@ -128,14 +132,14 @@ residualPlot.default <- function(model, variable = "fitted", type = "pearson",
   if(class(horiz) == "factor") {
      idm <- switch(id.method, xy="y", x="y", y="y", "none")  
      Boxplot(vert, horiz, xlab=lab, ylab=ylab, labels=labels, 
-            id.method=idm, id.n=id.n, id.cex=id.cex, 
+            id.method=idm, id.n=id.n, id.cex=id.cex,  
             id.col=id.col, ...) 
-     abline(h=0, lty=2) } else {
+     abline(h=0, lty=2) } else {    
      plot(horiz, vert, xlab=lab, ylab=ylab, ...)
 	  if(grid){
       grid(lty=1, equilogs=FALSE)
       box()}
-     points(horiz, vert, ...)
+     points(horiz, vert, col=col, ...)
      abline(h=0, lty=2)
      if(quadratic==TRUE){
         new <- seq(min(horiz), max(horiz), length=200)
